@@ -1,21 +1,23 @@
-use std::env;
 use std::error::Error;
-use std::fs::{create_dir, rename};
-use std::io::Cursor;
-use std::path::Path;
-
-use encoding::all::EUC_JP;
-use encoding::{EncoderTrap, Encoding};
-use flate2::read::GzDecoder;
-use tar::Archive;
-use tokio::fs::File;
-use tokio::io::{AsyncReadExt, AsyncWriteExt};
-
-use lindera_core::dictionary_builder::DictionaryBuilder;
-use lindera_ipadic_builder::ipadic_builder::IpadicBuilder;
 
+#[cfg(feature = "ipadic")]
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn Error>> {
+    use std::env;
+    use std::fs::{create_dir, rename};
+    use std::io::Cursor;
+    use std::path::Path;
+
+    use encoding::all::EUC_JP;
+    use encoding::{EncoderTrap, Encoding};
+    use flate2::read::GzDecoder;
+    use tar::Archive;
+    use tokio::fs::File;
+    use tokio::io::{AsyncReadExt, AsyncWriteExt};
+
+    use lindera_core::dictionary_builder::DictionaryBuilder;
+    use lindera_ipadic_builder::ipadic_builder::IpadicBuilder;
+
     println!("cargo:rerun-if-changed=build.rs");
     println!("cargo:rerun-if-changed=Cargo.toml");
 
@@ -91,3 +93,9 @@ async fn main() -> Result<(), Box<dyn Error>> {
 
     Ok(())
 }
+
+#[cfg(not(feature = "ipadic"))]
+#[tokio::main]
+async fn main() -> Result<(), Box<dyn Error>> {
+    Ok(())
+}
