@@ -1,3 +1,4 @@
+#[cfg(feature = "ipadic")]
 use std::env;
 
 use lindera_core::character_definition::CharacterDefinitions;
@@ -21,41 +22,68 @@ macro_rules! decompress_data {
     };
 }
 
+#[cfg(feature = "ipadic")]
 decompress_data!(
     CHAR_DEFINITION_DATA,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/char_def.bin")),
     "char_def.bin"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(CHAR_DEFINITION_DATA, &[], "char_def.bin");
+
+#[cfg(feature = "ipadic")]
 decompress_data!(
     CONNECTION_DATA,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/matrix.mtx")),
     "matrix.mtx"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(CONNECTION_DATA, &[], "matrix.mtx");
+
+#[cfg(feature = "ipadic")]
 decompress_data!(
     IPADIC_DATA,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/dict.da")),
     "dict.da"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(IPADIC_DATA, &[], "dict.da");
+
+#[cfg(feature = "ipadic")]
 decompress_data!(
     IPADIC_VALS,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/dict.vals")),
     "dict.vals"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(IPADIC_VALS, &[], "dict.vals");
+
+#[cfg(feature = "ipadic")]
 decompress_data!(
     UNKNOWN_DATA,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/unk.bin")),
     "unk.bin"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(UNKNOWN_DATA, &[], "unk.bin");
+
+#[cfg(feature = "ipadic")]
 decompress_data!(
     WORDS_IDX_DATA,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/dict.wordsidx")),
     "dict.wordsidx"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(WORDS_IDX_DATA, &[], "dict.wordsidx");
+
+#[cfg(feature = "ipadic")]
 decompress_data!(
     WORDS_DATA,
     include_bytes!(concat!(env!("OUT_DIR"), "/lindera-ipadic/dict.words")),
     "dict.words"
 );
+#[cfg(not(feature = "ipadic"))]
+decompress_data!(WORDS_DATA, &[], "dict.words");
 
 pub fn char_def() -> LinderaResult<CharacterDefinitions> {
     CharacterDefinitions::load(&CHAR_DEFINITION_DATA)
